@@ -1575,6 +1575,7 @@ class Update(MethodsInterface):
                     # SUCCESS
                     if not binhost.downgraded or stabilization:
                         host = "-> %s" % host
+                        #TODO add migration binhost check there
                         reason = self.Reason.Success
                     else:
                         reason = self.Reason.Skip
@@ -1761,3 +1762,9 @@ class Update(MethodsInterface):
                 except Exception:
                     pass
         return True
+        
+    def update_set_current_level(self):
+        # print("DEBUG")
+        # self.clVars.Get('update.cl_update_binhost'))
+        self.printSUCCESS(_("UPDATE LEVEL %s") % self.clVars.Get('update.cl_update_level'))
+        return True
