@@ -1561,6 +1561,13 @@ class VariableClUpdateBinhostUnstableList(Variable):
     value = ["https://testing.calculate-linux.org/"]
     # value = ["ftp://ftp.calculate-linux.ru/testing"]
 
+class VariableClUpdateBinhostListMigration(Variable):
+    """
+    Список хостов с бинарными обновлениями для стабильной миграции
+    """
+    type = "list"
+    #TODO placeholder
+    value = ["https://testing.calculate-linux.org/"]
 
 class VariableClUpdateBinhostBase(Variable):
     """
@@ -1845,3 +1852,10 @@ class VariableClUpdatePortageBinhostPath(Variable):
     Файл в котором хранится параметр portage PORTAGE_BINHOST
     """
     value = "/etc/portage/make.conf/binhost"
+
+class VariableClUpdateLevel(Variable):
+    """
+    Текущий уровень обновления
+    Используется для выбора зеркала
+    """
+    value = "0"
\ No newline at end of file
